Brown Paper Tickets - The fair-trade ticketing company.
Description: Brown Paper Tickets - The first and only fair trade ticketing company!
Keywords: ticket buy sell tickets events event registration

| View site in English, Español, or Français

| The fair-trade ticketing company. |
Sign Me Up! | | | Log In |
Go | Forget your login?

Find An Event | Create Your Event | Help

# Find an event
## Search Options KEYWORDS CATEGORY LOCATION DATE
| - |
PRICE RANGE
| - |
| Discount Tickets Only
ADDITIONAL OPTIONS
| Kid Friendly
| Dog Friendly
| Non-Smoking
| Wheelchair Accessible
Start Over
Events | Showing 1-20 of 9291
Sort by Name | Sort by Date | Sort by Distance from |
Default Location Cancel
Change Location
| ## Dementia UK Carol Concert 2015 Wednesday 09 December 2015 7:00 PM - 09 December 2015 9:00 PM St George's Church London United Kingdom Carol Concert in aid of Dementia UK, St George's Church, Hanover Square, London on Wednesday 9th December 2014 at 7pm. | TODAY
| [View This Event!]
| ## Monti Walking Tour in Rome Wednesday 09 December 2015 10:30 AM - 31 January 2016 2:30 PM In front of REGOLI pastry shop (pasticceria) Rome Italy Includes Esquilino district and other great sites | TODAY
| [View This Event!]
| ## Panel discussion - Must the Arts Be Relevant? Wednesday 09 December 2015 3:00 PM - 09 December 2015 4:30 PM Rambert London United Kingdom Panel discussion presented in association with the 2015 British Composer Awards | TODAY FREE
| [View This Event!]
| ## Scenework drop in Wednesday 09 December 2015 7:00 PM - 23 December 2015 10:00 PM The Nursery Training Centre London United Kingdom Polishing your scenes | TODAY
| [View This Event!]
| ## Small-Group Evening Sightseeing Walking Tour Wednesday 09 December 2015 5:45 PM - 29 July 2016 10:00 PM Jewish Ghetto Area Rome Italy Includes Piazza Navona, Campo de' Fiori, Jewish Ghetto | TODAY
| [View This Event!]
| ## The Strange Blue Dreams vs A New International - The December Trembler Round 1 Wednesday 09 December 2015 7:30 PM - 09 December 2015 11:00 PM The Hug and Pint Glasgow United Kingdom Round 1 of a joint-headline, two-band, two-city musical boxing match | TODAY
| [View This Event!]
| ## Trevi & Pantheon Walking Tour Wednesday 09 December 2015 11:00 AM - 30 January 2016 3:00 PM Campo de' Fiori at the feet of the statue of philosopher Giordano Bruno Rome Italy Includes Trevi, Pantheon and other great sites | TODAY
| [View This Event!]
| ## A New International vs The Strange Blue Dreams - The December Trembler Round 2 Thursday 10 December 2015 7:30 PM - 10 December 2015 10:30 PM The Banshee Labyrinth Edinburgh United Kingdom Round 2 of a joint-headline, two-band, two-city musical boxing match | TOMORROW
| [View This Event!]
| ## Christmas Decoration Class Thursday 10 December 2015 6:30 PM - 10 December 2015 9:00 PM St Margaret's House, Studio 5.20C Edinburgh United Kingdom evening class making beautiful fabric Christmas decorations, ideal for gifts too! £20 | TOMORROW
| [View This Event!]
| ## Cirque du Cabaret Winterville Shows, 2015 Victoria Park, Spiegeltent Thursday 10 December 2015 7:00 PM - 17 December 2015 10:00 PM Spiegeltent, Victory Park London London United Kingdom Set in the heart of Victoria Park, a glorious Spiegeltent will host 3 x spectacular Cirque du Cabaret shows from November 26th to December 17th | TOMORROW
| [View This Event!]
| ## #ClimateKilometre cycle to COP21, accommodation on 10/12/2015 (Gancourt) and bag-drop van Thursday 10 December 2015 6:00 PM - 11 December 2015 9:00 AM Gancourt Seine-maritime France Accommodation on Thurs 10th December 2015 (Gancourt) and bag-drop van | TOMORROW
| [View This Event!]
| ## #ClimateKilometre cycle to COP21, accommodation on 10/12/2015 (Gancourt) and bag-drop van Thursday 10 December 2015 6:00 PM - 11 December 2015 9:00 AM Gancourt Seine-maritime France Accommodation on Thurs 10th December 2015 (Gancourt) and bag-drop van | TOMORROW
| [View This Event!]
| ## Ergo Sum R&D Thursday 10 December 2015 6:30 PM - 11 December 2015 10:00 PM Theatre Delicatessan London United Kingdom Ergo Sum is a multi-sensory exploration of the human mind utilising a combination of 3D binaural sound-scape and live performance. | TOMORROW
| [View This Event!]
| ## Love, Marriage... And Life! Thursday 10 December 2015 8:00 PM - 13 December 2015 4:00 PM Margaret Howard Theatre Bushey United Kingdom A Cabaret Evening of Song & Dance | TOMORROW
| [View This Event!]
| ## Pregnancy SOS Thursday 10 December 2015 6:30 PM - 10 December 2015 9:00 PM Raw Press Cafe London United Kingdom Event providing information on how to get ready for pregnancy | TOMORROW
| [View This Event!]
| ## Snow White and the Seven Dwarfs Thursday 10 December 2015 7:00 PM - 12 December 2015 10:00 PM The Treehouse Fareham United Kingdom A family pantomime by Bob Heather and Cheryl Barrett | TOMORROW
| [View This Event!]
| ## The Fun Cooking Class, Jan - Aug 2015 Thursday 10 December 2015 10:30 AM - 31 December 2015 2:30 PM The Fun Cooking Class Saint Mandé France What no restaurants can offer | TOMORROW
| [View This Event!]
| ## A Christmas Carol Friday 11 December 2015 2:00 PM - 11 December 2015 8:30 PM Chester Music Theatre Chester United Kingdom A Musical Family Christmas Show | THIS WEEK
| [View This Event!]
| ## A Christmas Carol Friday 11 December 2015 2:00 PM - 11 December 2015 8:30 PM Chester Music Theatre Chester, United Kingdom Family musical adaptation, filled with puppetry, colourful characters and multimedia! | THIS WEEK
| [View This Event!]
| ## A Christmas Line Friday 11 December 2015 7:00 PM - 13 December 2015 5:00 PM Paramount Theatre Casa Grande, AZ "A Christmas Line" North Pole Musical a Fun Holiday Celebration for the entire family. 3 showtimes Dec11, 12, & 13 Tickets $15.00 Adult, $12.00 Senior & $6.00 Child | THIS WEEK
| [View This Event!]
1 | 2 | 3 | 4 | 5 | 6 | 7 | 8 | 9 | Next

Contact us
Email
support@brownpapertickets.com
24/7 Customer Service
1-800-838-3006 US, Canada, Puerto Rico
Resources
Careers
Press
Developers
Help
Ticket Buyers
Track Your Order
Browse Events
Locations
Event Producers
Create an Event
Pricing
Services
Buy Pre-Printed Tickets
The Venue List

Join the mailing list
Get spam-free daily notifications of new events in your neighborhood!
Customize your mailing list

Connect with us

| Friend us on Facebook
| Follow us on Twitter
| Watch us on YouTube
| Read our blog
| Get to know us
| Meet the Doers

Use of Brown Paper Tickets is subject to our Terms & Conditions. All rights reserved. © 2000-2015 | Mobile EN ES FR